@@ -26,6 +26,7 @@
 import fnmatch
 import sys
 import humanfriendly
+import re
 
 from PyQt5.QtCore import pyqtProperty
 from PyQt5.QtWidgets import QWidget, QLabel, QHBoxLayout
@@ -36,6 +37,14 @@ FOLDER_SPACES = 11
 FILES_SPACES = 12
 
 
+def get_extension_from_string(text):
+    pattern = re.search(r'\((.*?)\)', text).group(1)
+    pattern = pattern.split()
+    if isinstance(pattern, list):
+        return pattern
+    else:
+        return [pattern]
+
 def match_extension(name, extensions=None):
     """
     Determines if a file name matches an extension
